==> rsuite-5.49.0.tgz: package/esm/locales/sv_SE.js <==
'use client';
import _extends from "@babel/runtime/helpers/esm/extends";
import sv from 'date-fns/locale/sv';
var Calendar = {
  sunday: 'Sö',
  monday: 'Må',
  tuesday: 'Ti',
  wednesday: 'On',
  thursday: 'To',
  friday: 'Fr',
  saturday: 'Lö',
  ok: 'OK',
  today: 'I dag',
  yesterday: 'I går',
  hours: 'Timmar',
  minutes: 'Minuter',
  seconds: 'Sekunder',
  /**
   * Format of the string is based on Unicode Technical Standard #35:
   * https://www.unicode.org/reports/tr35/tr35-dates.html#Date_Field_Symbol_Table
   **/
  formattedMonthPattern: 'MMM yyyy',
  formattedDayPattern: 'dd MMM yyyy',
  dateLocale: sv
};
export default {
  common: {
    loading: 'Laddar...',
    emptyMessage: 'Kunde inte hitta data',
    remove: 'Ta bort',
    clear: 'Rensa'
  },
  Plaintext: {
    unfilled: 'Ofylld',
    notSelected: 'Ej valt',
    notUploaded: 'Ej uppladdad'
  },
  Pagination: {
    more: 'Mer',
    prev: 'Föregående',
    next: 'Nästa',
    first: 'Första',
    last: 'Sista',
    limit: '{0} / sida',
    total: 'totalt: {0}',
    skip: 'Gå til{0}'
  },
  Calendar: Calendar,
  DatePicker: _extends({}, Calendar),
  DateRangePicker: _extends({}, Calendar, {
    last7Days: 'Senaste 7 dagarna'
  }),
  Picker: {
    noResultsText: 'Inga resultat funna',
    placeholder: 'Välj',
    searchPlaceholder: 'Sök',
    checkAll: 'Alla'
  },
  InputPicker: {
    newItem: 'Ny inkorg',
    createOption: 'Skapa meddelande "{0}"'
  },
  Uploader: {
    inited: 'Första',
    progress: 'Uppladdning',
    error: 'Fel',
    complete: 'Färdig',
    emptyFile: 'Tom',
    upload: 'Ladda upp',
    removeFile: 'Radera filer'
  },
  CloseButton: {
    closeLabel: 'Stänga av'
  },
  Breadcrumb: {
    expandText: 'Visa väg'
  },
  Toggle: {
    on: 'På',
    off: 'Av'
  }
};

==> rsuite-5.73.1.tgz: package/esm/locales/sv_SE.js <==
'use client';
import _extends from "@babel/runtime/helpers/esm/extends";
import sv from 'date-fns/locale/sv';
var DateTimeFormats = {
  sunday: 'Sö',
  monday: 'Må',
  tuesday: 'Ti',
  wednesday: 'On',
  thursday: 'To',
  friday: 'Fr',
  saturday: 'Lö',
  ok: 'OK',
  today: 'I dag',
  yesterday: 'I går',
  now: 'Nu',
  hours: 'Timmar',
  minutes: 'Minuter',
  seconds: 'Sekunder',
  /**
   * Format of the string is based on Unicode Technical Standard #35:
   * https://www.unicode.org/reports/tr35/tr35-dates.html#Date_Field_Symbol_Table
   **/
  formattedMonthPattern: 'MMM yyyy',
  formattedDayPattern: 'dd MMM yyyy',
  shortDateFormat: 'yyyy-MM-dd',
  shortTimeFormat: 'HH:mm',
  dateLocale: sv
};
export default {
  code: 'sv-SE',
  common: {
    loading: 'Laddar...',
    emptyMessage: 'Kunde inte hitta data',
    remove: 'Ta bort',
    clear: 'Rensa'
  },
  Plaintext: {
    unfilled: 'Ofylld',
    notSelected: 'Ej valt',
    notUploaded: 'Ej uppladdad'
  },
  Pagination: {
    more: 'Mer',
    prev: 'Föregående',
    next: 'Nästa',
    first: 'Första',
    last: 'Sista',
    limit: '{0} / sida',
    total: 'totalt: {0}',
    skip: 'Gå til{0}'
  },
  Calendar: _extends({}, DateTimeFormats),
  DatePicker: _extends({}, DateTimeFormats),
  DateRangePicker: _extends({}, DateTimeFormats, {
    last7Days: 'Senaste 7 dagarna'
  }),
  Picker: {
    noResultsText: 'Inga resultat funna',
    placeholder: 'Välj',
    searchPlaceholder: 'Sök',
    checkAll: 'Alla'
  },
  InputPicker: {
    newItem: 'Ny inkorg',
    createOption: 'Skapa meddelande "{0}"'
  },
  Uploader: {
    inited: 'Första',
    progress: 'Uppladdning',
    error: 'Fel',
    complete: 'Färdig',
    emptyFile: 'Tom',
    upload: 'Ladda upp',
    removeFile: 'Radera filer'
  },
  CloseButton: {
    closeLabel: 'Stänga av'
  },
  Breadcrumb: {
    expandText: 'Visa väg'
  },
  Toggle: {
    on: 'På',
    off: 'Av'
  }
};
